@@ -12,8 +12,8 @@ Tools and Utilities for debugging and helping with development of Editra.
 
 """
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: dev_tool.py 59092 2009-02-22 19:13:56Z CJP $"
-__revision__ = "$Revision: 59092 $"
+__svnid__ = "$Id: dev_tool.py 60454 2009-05-01 01:20:04Z CJP $"
+__revision__ = "$Revision: 60454 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -23,6 +23,7 @@ import re
 import platform
 import traceback
 import time
+import urllib2
 import webbrowser
 import codecs
 import locale
@@ -415,7 +416,11 @@ class ErrorDialog(wx.Dialog):
         elif e_id == ID_SEND:
             msg = "mailto:%s?subject=Error Report&body=%s"
             addr = "bugs@%s" % (ed_glob.HOME_PAGE.replace("http://", '', 1))
-            msg = msg % (addr, self.err_msg)
+            if wx.Platform != '__WXMAC__':
+                msg = urllib2.quote(self.err_msg)
+            else:
+                msg = self.err_msg
+            msg = msg % (addr, msg)
             msg = msg.replace("'", '')
             webbrowser.open(msg)
             self.Close()
