@@ -12,11 +12,13 @@ Editra Buisness Model Library:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: __init__.py 60249 2009-04-20 01:18:29Z CJP $"
-__revision__ = "$Revision: 60249 $"
+__cvsid__ = "$Id: __init__.py 60465 2009-05-02 00:16:48Z CJP $"
+__revision__ = "$Revision: 60465 $"
 
 #-----------------------------------------------------------------------------#
 
+# Text Utils
 from searcheng import *
 from fchecker import *
 from fileutil import *
+from fileimpl import *
