@@ -18,8 +18,8 @@ a gradient using system defined colors.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_cmdbar.py 59256 2009-03-02 00:52:16Z CJP $"
-__revision__ = "$Revision: 59256 $"
+__svnid__ = "$Id: ed_cmdbar.py 60041 2009-04-06 15:03:46Z CJP $"
+__revision__ = "$Revision: 60041 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -161,7 +161,7 @@ class SearchBar(CommandBarBase):
         # HACK: workaround bug in mac control that resets size to
         #       that of the default variant after any text has been
         #       typed in it. Note it reports the best size as the default
-        #       variant and causes layout issues. wxBUG 
+        #       variant and causes layout issues. wxBUG
         if wx.Platform == '__WXMAC__':
             self.ctrl.SetSizeHints(180, 16, 180, 16)
 
@@ -256,7 +256,7 @@ class CommandEntryBar(CommandBarBase):
         # HACK: workaround bug in mac control that resets size to
         #       that of the default variant after any text has been
         #       typed in it. Note it reports the best size as the default
-        #       variant and causes layout issues. wxBUG 
+        #       variant and causes layout issues. wxBUG
         if wx.Platform == '__WXMAC__':
             self.ctrl.SetSizeHints(150, 16, 150, 16)
 
@@ -280,7 +280,7 @@ class GotoLineBar(CommandBarBase):
         # HACK: workaround bug in mac control that resets size to
         #       that of the default variant after any text has been
         #       typed in it. Note it reports the best size as the default
-        #       variant and causes layout issues. wxBUG 
+        #       variant and causes layout issues. wxBUG
         if wx.Platform == '__WXMAC__':
             self.ctrl.SetSizeHints(100, 16, 100, 16)
 
@@ -557,33 +557,36 @@ class CommandExecuter(eclib.CommandEntryBase):
         @keyword files: Get list of files too
 
         """
-        replace = 0
-        if path.startswith("~/") or path.startswith("~\\"):
-            prefix = wx.GetHomeDir()
-            replace = len(prefix) + 1
-            path = os.path.join(prefix, path[2:])
-        elif not path.startswith(os.sep):
-            prefix = self._curdir
-            replace = len(prefix)
-            path = os.path.join(prefix, path)
-        else:
-            pass
+        def append_slash(path):
+            """Helper function that appends a slash to the path
+            if it's a directory.
 
-        paths = []
-        for atom in glob.glob(path + "*"):
-            if os.path.isdir(atom) or files:
-                if replace > 0:
-                    atom = atom[replace:]
-                if os.path.isdir(atom) and atom[-1] != os.sep:
-                    atom += os.sep
-                paths.append(atom)
+            """
+            if os.path.isdir(path) and not path.endswith(os.sep):
+                return path + os.sep
+            return path
 
-        return sorted(list(set(paths)))
+        curdir = self._curdir
+        head, tail = os.path.split(path)
+        head = os.path.expanduser(head)
+        head = os.path.expandvars(head)
+        head = os.path.join(curdir, head)
+        if not os.path.isdir(head):
+            return []
+
+        # We expanded head, so trim the suggestion list of its head
+        # so we can add the tail of the suggestion back to the original head
+        candidates = [os.path.basename(p) for p in os.listdir(head)
+                      if p.startswith(tail)]
+        candidates = [append_slash(os.path.join(os.path.dirname(path), cand))
+                      for cand in candidates]
+        if not files:
+            candidates = [cand for cand in candidates if os.path.isdir(cand)]
+
+        return sorted(list(set(candidates)))
 
     def ListDir(self):
-        """List the next directory from the current cmd path
-
-        """
+        """List the next directory from the current cmd path"""
         cmd = self.GetValue()
         if cmd.startswith('cd '):
             cstr = 'cd '
@@ -596,15 +599,10 @@ class CommandExecuter(eclib.CommandEntryBase):
         paths = self.GetPaths(cmd, cstr == 'e ')
         self._popup.SetChoices(paths)
         if len(paths):
-            pos = self.GetScreenPosition().Get()
-            extent = self.GetTextExtent(cstr)
-            self._popup.SetPosition((pos[0] + extent[0],
-                                    pos[1] + extent[1] + 7))
-            self._popup.SetBestSelection(cmd)
+            self._popup.SetupPosition(self)
             if not self._popup.IsShown():
                 self._popup.Show()
-        else:
-            self._popup.Hide()
+
         self.SetInsertionPoint(self.GetLastPosition())
 
     def OnEnter(self, evt):
@@ -612,10 +610,11 @@ class CommandExecuter(eclib.CommandEntryBase):
         @postcondition: ctrl is cleared and command is executed
 
         """
-        if self._popup.IsShown():
+        if self._popup.HasSuggestions() and self._popup.HasSelection():
             psel = self._popup.GetSelection()
             if self.GetValue().split(' ', 1)[-1].strip() != psel:
                 self._AdjustValue(psel)
+                self._popup.Hide()
                 return
 
         cmd = self.GetValue()
@@ -632,13 +631,14 @@ class CommandExecuter(eclib.CommandEntryBase):
         """
         e_key = evt.GetKeyCode()
         cmd = self.GetValue()
+
         if e_key == wx.WXK_UP:
-            if self._popup.IsShown():
+            if self._popup.HasSuggestions():
                 self._popup.AdvanceSelection(False)
             else:
                 self.GetHistCommand(pre=True)
         elif e_key == wx.WXK_DOWN:
-            if self._popup.IsShown():
+            if self._popup.HasSuggestions():
                 self._popup.AdvanceSelection(True)
             else:
                 self.GetHistCommand(pre=False)
@@ -648,14 +648,17 @@ class CommandExecuter(eclib.CommandEntryBase):
         elif e_key == wx.WXK_TAB:
             # Provide Tab Completion or swallow key
             if cmd.startswith('cd ') or cmd.startswith('e '):
-                if self._popup.IsShown():
+                if self._popup.HasSuggestions():
                     self._AdjustValue(self._popup.GetSelection())
                 self.ListDir()
             else:
                 pass
         elif e_key == wx.WXK_ESCAPE:
-            self.Clear()
-            self.GetParent().Hide()
+            if self._popup.IsShown():
+                self._popup.Hide()
+            else:
+                self.Clear()
+                self.GetParent().Hide()
         else:
             evt.Skip()
 
@@ -665,8 +668,7 @@ class CommandExecuter(eclib.CommandEntryBase):
 
         """
         val = self.GetValue()
-        if self._popup.IsShown() and \
-           evt.GetKeyCode() not in [wx.WXK_DOWN, wx.WXK_UP]:
+        if self._popup.IsShown():
             if not len(val):
                 self._popup.Hide()
             else:
@@ -720,14 +722,12 @@ class CommandExecuter(eclib.CommandEntryBase):
         @param value: string to set value of control to
 
         """
-        wx.SearchCtrl.SetValue(self, value)
+        super(CommandExecuter, self).SetValue(value)
         self._AdjustSize()
 
     def UpdateAutoComp(self):
         """Update the autocomp list for paths that best match current value"""
         self.ListDir()
-        val = self.GetValue().split(' ', 1)[-1]
-        self._popup.SetBestSelection(val)
 
     def WriteCommand(self, cstr):
         """Perform a file write related command
@@ -752,8 +752,8 @@ class LineCtrl(eclib.CommandEntryBase):
 
         """
         eclib.CommandEntryBase.__init__(self, parent, id_, "", size=size,
-                                           style=wx.TE_PROCESS_ENTER,
-                                           validator=util.IntValidator(0, 65535))
+                                        style=wx.TE_PROCESS_ENTER,
+                                        validator=util.IntValidator(0, 65535))
 
         # Attributes
         self._last = 0
@@ -886,6 +886,18 @@ class PopupList(wx.MiniFrame):
         """
         return self._list.GetStringSelection()
 
+    def HasSelection(self):
+        """Tells whether anything in the list is selected"""
+        return self._list.GetSelection() != wx.NOT_FOUND
+
+    def HasSuggestions(self):
+        """Tell whether the list is showing suggestions"""
+        return self.IsShown() and self.ListCount() > 0
+
+    def ListCount(self):
+        """return the number of elements in the popup list"""
+        return self._list.GetCount()
+
     def OnFocus(self, evt):
         """Raise and reset the focus to the parent window whenever
         we get focus.
@@ -926,7 +938,7 @@ class PopupList(wx.MiniFrame):
         @keyword show: Should the window be shown or not
 
         """
-        res = wx.Frame.Show(self, show)
+        res = super(PopupList, self).Show(show)
 
         if res and show:
             self.ActivateParent()
@@ -941,7 +953,13 @@ class PopupList(wx.MiniFrame):
         @param choices: list of strings
 
         """
+        selection = self._list.GetSelection()
         self._list.SetItems(choices)
+        count = self._list.GetCount()
+        if selection == wx.NOT_FOUND or selection >= count:
+            selection = 0
+        if count > 0:
+            self._list.SetSelection(selection)
 
     def SetSelection(self, index):
         """Set the selection in the list by index
@@ -957,27 +975,20 @@ class PopupList(wx.MiniFrame):
         """
         self._list.SetStringSelection(text)
 
-    def SetBestSelection(self, prefix):
-        """Set the selection to the one that bests matches the
-        given string.
-        @param prefix: prefix to set selection of
-        @note: searches for a match recursively, if no partial match is found
-               then the first item in the list is selected.
+    def SetupPosition(self, cmd_ex):
+        """Sets size and position of widget
+        @param cmd_ex: CommandExecuter window
 
         """
-        if not len(prefix):
-            if len(self._list.GetStrings()):
-                self._list.SetSelection(0)
-                self.ActivateParent()
-        else:
-            matches = [item for item in self._list.GetItems()
-                       if item.startswith(prefix) ]
-            if len(matches):
-                self._list.SetStringSelection(sorted(matches)[0])
-                self.ActivateParent()
-            else:
-                self.SetBestSelection(prefix[:-1])
+        cmd = cmd_ex.GetValue()
+        cmd = cmd.split(u' ', 1)[0]
+        xpos = cmd_ex.GetTextExtent(cmd + u' ')[0]
+        pos = cmd_ex.GetScreenPosition().Get()
+        csize = cmd_ex.GetSize()
+        self.SetPosition((pos[0] + xpos, pos[1] + csize[1]))
+        self.ActivateParent()
 
+#----------------------------------------------------------------------------#
 
 class PopupWinList(wx.PopupWindow):
     """Popuplist for Windows/GTK"""
@@ -988,7 +999,7 @@ class PopupWinList(wx.PopupWindow):
         # Attributes
         self._list = wx.ListBox(self, choices=choices, pos=(0, 0),
                                 style=wx.LC_REPORT | wx.LC_SINGLE_SEL |
-                                      wx.LC_NO_HEADER | wx.NO_BORDER)
+                                      wx.LC_NO_HEADER)
 
         # Layout
         sizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -1006,17 +1017,33 @@ class PopupWinList(wx.PopupWindow):
         @keyword down: move selection down or up
 
         """
+        item_count = self._list.GetCount()
+        if item_count == 0:
+            return
         csel = self._list.GetSelection()
-        if csel != wx.NOT_FOUND:
+        if csel == wx.NOT_FOUND:
+            if down:
+                csel = 0
+            else:
+                csel = -1
+        else:
             if down:
                 csel += 1
             else:
                 csel -= 1
-                csel = max(csel, 0)
 
-            if csel < len(self._list.GetItems()):
-                self._list.SetSelection(csel)
-                self._list.EnsureVisible(csel)
+        # If it's -1 actually, but just in case something
+        # crazy happens and it drops even below -1
+        if csel < 0:
+            csel = item_count - 1
+        if csel >= item_count:
+            csel = 0
+        self._list.SetSelection(csel)
+        self._list.EnsureVisible(csel)
+
+    def GetListCtrl(self):
+        """Get the ListBox control of the popupwindow"""
+        return self._list
 
     def GetSelection(self):
         """Get the string that is currently selected in the list
@@ -1025,6 +1052,18 @@ class PopupWinList(wx.PopupWindow):
         """
         return self._list.GetStringSelection()
 
+    def HasSelection(self):
+        """Tells whether anything in the list is selected"""
+        return self._list.GetSelection() != wx.NOT_FOUND
+
+    def HasSuggestions(self):
+        """Tell whether the list is showing suggestions"""
+        return self.IsShown() and self.ListCount() > 0
+
+    def ListCount(self):
+        """return the number of elements in the popup list"""
+        return self._list.GetCount()
+
     def OnSize(self, evt):
         """Resize the list box to the correct size to fit."""
         csz = self.GetClientSize()
@@ -1032,41 +1071,39 @@ class PopupWinList(wx.PopupWindow):
         self._list.SetSize(csz)
         evt.Skip()
 
-    def SetBestSelection(self, prefix):
-        """Set the selection to the one that bests matches the
-        given string.
-        @param prefix: prefix to set selection of
-        @note: searches for a match recursively, if no partial match is found
-               then the first item in the list is selected.
+    def SetupPosition(self, cmd_ex):
+        """Sets size and position of widget
+        @param cmd_ex: CommandExecuter window
 
         """
-        if not len(prefix):
-            if len(self._list.GetStrings()):
-                self._list.SetSelection(0)
-        else:
-            matches = [item for item in self._list.GetItems()
-                       if item.startswith(prefix) ]
-            if len(matches):
-                self._list.SetStringSelection(sorted(matches)[0])
-            else:
-                self.SetBestSelection(prefix[:-1])
-
+        cmd = cmd_ex.GetValue()
+        cmd = cmd.split(u' ', 1)[0]
+        pos = cmd_ex.GetScreenPosition().Get()
+        csize = cmd_ex.GetSize()
+        xpos = cmd_ex.GetTextExtent(cmd)[0]
         self._list.SetInitialSize()
         self.SetInitialSize()
+        self.SetPosition((pos[0] + xpos, pos[1] + csize[1]))
 
     def SetChoices(self, choices):
         """Set the available choices that are shown in the list
         @param choices: list of strings
 
         """
+        selection = self._list.GetSelection()
         self._list.SetItems(choices)
+        count = self._list.GetCount()
+        if selection == wx.NOT_FOUND or selection >= count:
+            selection = 0
+        if count > 0:
+            self._list.SetSelection(selection)
 
     def Show(self, show=True):
         """Adjust size of popup and then show it
         @keyword show: Should the window be shown or not
 
         """
-        res = wx.PopupWindow.Show(self, show)
+        res = super(PopupWinList, self).Show(show)
 
         self._list.Show()
         self._list.SetInitialSize()
