@@ -14,8 +14,8 @@ access point for all common variables in the project.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 59569 2009-03-16 03:40:34Z CJP $"
-__revision__ = "$Revision: 59569 $"
+__svnid__ = "$Id: ed_glob.py 60376 2009-04-26 04:35:42Z CJP $"
+__revision__ = "$Revision: 60376 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL',
@@ -24,6 +24,7 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_COPY', 'ID_PASTE', 'ID_SELECTALL', 'ID_ADD_BM',
             'ID_DEL_ALL_BM', 'ID_LINE_AFTER', 'ID_LINE_BEFORE', 'ID_CUT_LINE',
             'ID_COPY_LINE', 'ID_JOIN_LINES', 'ID_TRANSPOSE', 'ID_DELETE_LINE',
+            'ID_LINE_MOVE_UP', 'ID_LINE_MOVE_DOWN',
             'ID_QUICK_FIND', 'ID_PREF', 'ID_ZOOM_OUT',
             'HOME_PAGE', 'CONTACT_MAIL', 'ID_ZOOM_IN', 'ID_ZOOM_NORMAL',
             'ID_SHOW_EDGE', 'ID_SHOW_EOL', 'ID_SHOW_LN', 'ID_SHOW_WS',
@@ -65,8 +66,10 @@ import wxcompat
 # Values set when main loads
 CONFIG = {
           'CONFIG_BASE' : None, # Set if config base is in nonstandard location
+          'INSTALL_DIR' : "",   # Instal directory
           'CONFIG_DIR'  : "",   # Root configration directory
           'CACHE_DIR'   : "",   # Holds temp data about documents
+          'KEYPROF_DIR' : "",   # System Keybinding
           'PROFILE_DIR' : "",   # User Profile Directory
           'PLUGIN_DIR'  : "",   # User Plugin Dir
           'SYSPIX_DIR'  : "",   # Editras non user graphics
@@ -127,6 +130,8 @@ ID_COPY_LINE     = wx.NewId()
 ID_DUP_LINE      = wx.NewId()
 ID_JOIN_LINES    = wx.NewId()
 ID_TRANSPOSE     = wx.NewId()
+ID_LINE_MOVE_UP  = wx.NewId()
+ID_LINE_MOVE_DOWN= wx.NewId()
 ID_FIND          = wx.ID_FIND
 ID_FIND_PREVIOUS = wx.NewId()
 ID_FIND_NEXT     = wx.NewId()
@@ -145,6 +150,7 @@ ID_PREF          = wx.ID_PREFERENCES
 ID_PREF_LANG     = wx.NewId()
 ID_PREF_AALIAS   = wx.NewId()
 ID_PREF_AUTO_RELOAD = wx.NewId()
+ID_PREF_AUTOCOMPEX = wx.NewId()
 ID_PREF_AUTOTRIM = wx.NewId()
 ID_PREF_CHKMOD   = wx.NewId()
 ID_PREF_CHKUPDATE = wx.NewId()
@@ -277,6 +283,15 @@ ID_VI_MODE           = wx.NewId()
 ID_WEB               = wx.NewId()
 ID_READONLY          = wx.NewId()
 
+# Code Elements (ids for art provider)
+ID_CLASS_TYPE = wx.NewId()
+ID_FUNCT_TYPE = wx.NewId()
+ID_ELEM_TYPE = wx.NewId()
+ID_VARIABLE_TYPE = wx.NewId()
+ID_ATTR_TYPE = wx.NewId()
+ID_PROPERTY_TYPE = wx.NewId()
+ID_METHOD_TYPE = wx.NewId()
+
 # Statusbar IDs
 SB_INFO          = 0
 SB_BUFF          = 1
@@ -301,6 +316,7 @@ ID_2_PROF = {
              ID_PREF_UNINDENT     : 'BSUNINDENT',
              ID_APP_SPLASH        : 'APPSPLASH',
              ID_AUTOCOMP          : 'AUTO_COMP',
+             ID_PREF_AUTOCOMPEX   : 'AUTO_COMP_EX',
              ID_AUTOINDENT        : 'AUTO_INDENT',
              ID_PREF_AUTO_RELOAD  : 'AUTO_RELOAD',
              ID_PREF_AUTOTRIM     : 'AUTO_TRIM_WS',
