@@ -20,8 +20,8 @@ similar services for manipulating and transforming text.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: generator.py 56178 2008-10-09 02:10:37Z CJP $"
-__revision__ = "$Revision: 56178 $"
+__svnid__ = "$Id: generator.py 60250 2009-04-20 03:35:30Z CJP $"
+__revision__ = "$Revision: 60250 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -35,6 +35,7 @@ import ed_menu
 from ed_style import StyleItem
 import util
 import plugin
+import eclib
 
 #--------------------------------------------------------------------------#
 # Globals
@@ -255,7 +256,7 @@ class Html(plugin.Plugin):
                 last_id = curr_id
                 style_start = style_end
                 tag = stc.FindTagById(last_id)
-                if not self.css.has_key(tag):
+                if tag not in self.css:
                     s_item = StyleItem()
                     s_item.SetAttrFromStr(stc.GetStyleByName(tag))
                     self.css[tag] = CssItem(tag.split('_')[0], s_item)
@@ -294,11 +295,11 @@ class Html(plugin.Plugin):
 
         """
         # Must have the default style defined
-        if not self.css.has_key('default_style'):
+        if 'default_style' not in self.css:
             return
 
         # Don't style operators. This is to optimize the html size
-        if self.css.has_key('operator_style'):
+        if 'operator_style' in self.css:
             self.css.pop('operator_style')
 
         # All other css elements will inheirit from the default
@@ -926,7 +927,7 @@ class RtfColorTbl:
 
         """
         if si_color not in self._index:
-            rgb = util.HexToRGB(si_color.split(u',')[0])
+            rgb = eclib.HexToRGB(si_color.split(u',')[0])
             color = "\\red%d\\green%d\\blue%d;" % tuple(rgb)
             self._index.append(si_color)
             self._tbl[si_color] = color
