@@ -12,8 +12,8 @@ This file contains various helper functions and utilities that the program uses.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 60250 2009-04-20 03:35:30Z CJP $"
-__revision__ = "$Revision: 60250 $"
+__svnid__ = "$Id: util.py 60484 2009-05-02 18:53:43Z CJP $"
+__revision__ = "$Revision: 60484 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -443,6 +443,20 @@ def MakeConfigDir(name):
     except (OSError, IOError):
         pass
 
+def RepairConfigState(path):
+    """Repair the state of profile path, updating and creating it
+    it does not exist.
+    @param path: path of profile
+
+    """
+    if os.path.isabs(path) and os.path.exists(path):
+        return path
+    else:
+        # Need to fix some stuff up
+        CreateConfigDir()
+        import profiler
+        return profiler.Profile_Get("MYPROFILE")
+
 def CreateConfigDir():
     """ Creates the user config directory its default sub
     directories and any of the default config files.
@@ -472,6 +486,7 @@ def CreateConfigDir():
     import profiler
     profiler.Profile().LoadDefaults()
     profiler.Profile_Set("MYPROFILE", dest_file)
+    profiler.Profile().Write(dest_file)
     profiler.UpdateProfileLoader()
 
 def ResolvConfigDir(config_dir, sys_only=False):
