@@ -12,8 +12,8 @@ the util module.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: testUtil.py 59373 2009-03-06 17:20:59Z CJP $"
-__revision__ = "$Revision: 59373 $"
+__svnid__ = "$Id: testUtil.py 60250 2009-04-20 03:35:30Z CJP $"
+__revision__ = "$Revision: 60250 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -23,6 +23,8 @@ import unittest
 
 # Module to test
 import util
+import eclib
+import ebmlib
 
 #-----------------------------------------------------------------------------#
 # Test Class
@@ -41,12 +43,12 @@ class UtilTest(unittest.TestCase):
         c = wx.Colour(125, 125, 125)
 
         # Check that the color was brightened
-        c2 = util.AdjustColour(c, 50)
+        c2 = eclib.AdjustColour(c, 50)
         self.assertTrue(sum(c.Get()) < sum(c2.Get()),
                         "Failed to lighten colour")
 
         # Check that the color was darkened
-        c2 = util.AdjustColour(c, -50)
+        c2 = eclib.AdjustColour(c, -50)
         self.assertTrue(sum(c.Get()) > sum(c2.Get()),
                         "Failed to darken colour")
 
@@ -65,7 +67,7 @@ class UtilTest(unittest.TestCase):
 
     def testGetFileModTime(self):
         """Test getting a files modtime"""
-        mtime = util.GetFileModTime(self.path)
+        mtime = ebmlib.GetFileModTime(self.path)
         self.assertNotEqual(mtime, 0, "Mtime was: " + str(mtime))
 
     def testGetPathName(self):
